#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

APARID=LI74453
FIXFILENAME=libenunorm.so
#DESTDIR relative to $WVS_ROOT
DESTDIR=/IBM/ibmtts/lib

if [ ! "$2" ] 
then
  if [  -f ./LI74150.sh ]
 then
 echo "Ifix_LI74150: WVS Ifix $APARID Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_$APARID.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$APARID.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_$APARID: WVS Ifix $APARID Installer command syntax: "
 echo " to install ifix  syntax: ifix_$APARID -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$APARID.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/IBM/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   source /opt/IBM/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_ROOT" ] ; then
   echo "Ifix_$APARID: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_$APARID: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak ] ; then
    echo "Ifix_LI74150: Ifix $APARID is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_LI74150: Checking for ifix files ..."
  if [ -f $thisDir/$FIXFILENAME ] ; then
    if [ -f $thisDir/$FIXFILENAME ] ; then
      echo "Ifix_LI74150: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/$APARID
      cp -p $thisDir/$APARID.sh $WVS_ROOT/ifix/ifix_$APARID.sh
      
      cp -p $WVS_ROOT/$DESTDIR/$FIXFILENAME $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak    
      
      echo "Ifix_$APARID: Stopping WebSphere Application Server"
      $WAS_ROOT/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI74150: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/$APARID
         exit -1
      fi      
      
      cp -fbp $thisDir/$FIXFILENAME $WVS_ROOT/$DESTDIR/.
      
      chmod 755 $WVS_ROOT/$DESTDIR/$FIXFILENAME

      echo "Ifix_$APARID: Starting WebSphere Application Server"
      $WAS_ROOT/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_$APARID: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_$APARID: Ifix is now applied, please reboot the system"
      
    else
      echo "Ifix_$APARID: Ifix files missing, please be sure this script is in same directory as the binary files" 
    fi
  fi
  cp -fp $thisDir/$APARID.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_$APARID: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak ] ; then
    if [ -f $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak ] ; then
      echo "Ifix_$APARID: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_$APARID: Stopping WebSphere Application Server"
      $WAS_ROOT/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server stopped successful, proceeding to uninstall ifix"
      else
         echo "Ifix_$APARID: Application Server reported failure during stopping. Ifix uninstallation will not continue"
         rm -rf $WVS_ROOT/ifix/$APARID
         exit -1
      fi
      
      cp -fp $WVS_ROOT/ifix/$APARID/$FIXFILENAME.bak  $WVS_ROOT/$DESTDIR/$FIXFILENAME
	  
      chmod 755 $WVS_ROOT/$DESTDIR/$FIXFILENAME
          
      echo "Ifix_$APARID: Starting WebSphere Application Server"
      $WAS_ROOT/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_$APARID: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_$APARID: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       

      echo "Ifix_$APARID: Ifix is now uninstalled, please reboot the system"
      echo "Ifix_$APARID:  Please remove the $WVS_ROOT/ifix/$APARID directory before attempting a subsequent install of this ifix."
      
    else
      echo "Ifix_$APARID: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_$APARID: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
